==> openshift-model-hive-5.12.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/AWSDNSZoneSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AWSDNSZoneSpecBuilder extends io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpecFluentImpl<io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpec,io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpecBuilder>{
  public AWSDNSZoneSpecBuilder() {
    this(false);
  }
  public AWSDNSZoneSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new AWSDNSZoneSpec(), validationEnabled);
  }
  public AWSDNSZoneSpecBuilder(io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public AWSDNSZoneSpecBuilder(io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AWSDNSZoneSpec(), validationEnabled);
  }
  public AWSDNSZoneSpecBuilder(io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpecFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpec instance) {
    this(fluent, instance, false);
  }
  public AWSDNSZoneSpecBuilder(io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpecFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAdditionalTags(instance.getAdditionalTags()); 
    fluent.withCredentialsAssumeRole(instance.getCredentialsAssumeRole()); 
    fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef()); 
    fluent.withRegion(instance.getRegion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AWSDNSZoneSpecBuilder(io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpec instance) {
    this(instance,false);
  }
  public AWSDNSZoneSpecBuilder(io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAdditionalTags(instance.getAdditionalTags()); 
    this.withCredentialsAssumeRole(instance.getCredentialsAssumeRole()); 
    this.withCredentialsSecretRef(instance.getCredentialsSecretRef()); 
    this.withRegion(instance.getRegion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.AWSDNSZoneSpec build() {
    AWSDNSZoneSpec buildable = new AWSDNSZoneSpec(fluent.getAdditionalTags(),fluent.getCredentialsAssumeRole(),fluent.getCredentialsSecretRef(),fluent.getRegion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AWSDNSZoneSpecBuilder that = (AWSDNSZoneSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.4.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/AWSDNSZoneSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AWSDNSZoneSpecBuilder extends AWSDNSZoneSpecFluentImpl<AWSDNSZoneSpecBuilder> implements VisitableBuilder<AWSDNSZoneSpec,AWSDNSZoneSpecBuilder>{
  public AWSDNSZoneSpecBuilder() {
    this(false);
  }
  public AWSDNSZoneSpecBuilder(Boolean validationEnabled) {
    this(new AWSDNSZoneSpec(), validationEnabled);
  }
  public AWSDNSZoneSpecBuilder(AWSDNSZoneSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public AWSDNSZoneSpecBuilder(AWSDNSZoneSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AWSDNSZoneSpec(), validationEnabled);
  }
  public AWSDNSZoneSpecBuilder(AWSDNSZoneSpecFluent<?> fluent,AWSDNSZoneSpec instance) {
    this(fluent, instance, false);
  }
  public AWSDNSZoneSpecBuilder(AWSDNSZoneSpecFluent<?> fluent,AWSDNSZoneSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAdditionalTags(instance.getAdditionalTags()); 
    fluent.withCredentialsAssumeRole(instance.getCredentialsAssumeRole()); 
    fluent.withCredentialsSecretRef(instance.getCredentialsSecretRef()); 
    fluent.withRegion(instance.getRegion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AWSDNSZoneSpecBuilder(AWSDNSZoneSpec instance) {
    this(instance,false);
  }
  public AWSDNSZoneSpecBuilder(AWSDNSZoneSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAdditionalTags(instance.getAdditionalTags()); 
    this.withCredentialsAssumeRole(instance.getCredentialsAssumeRole()); 
    this.withCredentialsSecretRef(instance.getCredentialsSecretRef()); 
    this.withRegion(instance.getRegion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  AWSDNSZoneSpecFluent<?> fluent;
  Boolean validationEnabled;
  public AWSDNSZoneSpec build() {
    AWSDNSZoneSpec buildable = new AWSDNSZoneSpec(fluent.getAdditionalTags(),fluent.getCredentialsAssumeRole(),fluent.getCredentialsSecretRef(),fluent.getRegion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
